@@ -6,7 +6,6 @@
 #include "kdf.h"
 
 #include "kdf_version.h"
-#include <kxmlgui_version.h>
 #include <KAboutData>
 #include <KXMLGUIFactory>
 #include <KStandardShortcut>
@@ -17,9 +16,6 @@
 #include <QApplication>
 #include <QCommandLineParser>
 
-static const char description[] =
-    I18N_NOOP("KDE free disk space utility");
-
 /***************************************************************/
 KDFTopLevel::KDFTopLevel(QWidget *)
         : KXmlGuiWindow(nullptr)
@@ -52,7 +48,9 @@ void KDFTopLevel::closeEvent(QCloseEvent *event)
 int main(int argc, char **argv)
 {
     //Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kdf");
@@ -60,7 +58,7 @@ int main(int argc, char **argv)
     KAboutData aboutData(QStringLiteral("kdf"),
                          i18n("KDiskFree"),
                          QStringLiteral(KDF_VERSION_STRING),
-                         i18n(description),
+                         i18n("KDE free disk space utility"),
                          KAboutLicense::GPL,
                          i18n("(c) 1998-2001, Michael Kropfberger"),
                          QString(),
